Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(170)

Unified Diff: tests/corelib/splay_tree_from_iterables_test.dart

Issue 18072004: Add fromIterable(s) constructors in SplayTreeMap and LinkedHashMap. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Removed long line. Created 7 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tests/corelib/splay_tree_from_iterable_test.dart ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tests/corelib/splay_tree_from_iterables_test.dart
diff --git a/tests/corelib/map_from_iterables_test.dart b/tests/corelib/splay_tree_from_iterables_test.dart
similarity index 63%
copy from tests/corelib/map_from_iterables_test.dart
copy to tests/corelib/splay_tree_from_iterables_test.dart
index 8c21e9f6b2ced4971c45672988ace394a07aa040..5ac195ff6729bcad61439eb8a9639cd78bf88c51 100644
--- a/tests/corelib/map_from_iterables_test.dart
+++ b/tests/corelib/splay_tree_from_iterables_test.dart
@@ -15,9 +15,11 @@ main() {
}
void positiveTest() {
- var map = new Map.fromIterables([1, 2, 3], ["one", "two", "three"]);
+ var map = new SplayTreeMap.fromIterables([1, 2, 3], ["one", "two", "three"]);
+
Expect.isTrue(map is Map);
- Expect.isTrue(map is HashMap);
+ Expect.isTrue(map is SplayTreeMap);
+ Expect.isFalse(map is HashMap);
Expect.equals(3, map.length);
Expect.equals(3, map.keys.length);
@@ -29,9 +31,11 @@ void positiveTest() {
}
void emptyMapTest() {
- var map = new Map.fromIterables([], []);
+ var map = new SplayTreeMap.fromIterables([], []);
+
Expect.isTrue(map is Map);
- Expect.isTrue(map is HashMap);
+ Expect.isTrue(map is SplayTreeMap);
+ Expect.isFalse(map is HashMap);
Expect.equals(0, map.length);
Expect.equals(0, map.keys.length);
@@ -39,17 +43,19 @@ void emptyMapTest() {
}
void fewerValuesIterableTest() {
- Expect.throws(() => new Map.fromIterables([1,2], [0]));
+ Expect.throws(() => new SplayTreeMap.fromIterables([1,2], [0]));
}
void fewerKeysIterableTest() {
- Expect.throws(() => new Map.fromIterables([1], [0,2]));
+ Expect.throws(() => new SplayTreeMap.fromIterables([1], [0,2]));
}
void equalElementsTest() {
- var map = new Map.fromIterables([1, 2, 2], ["one", "two", "three"]);
+ var map = new SplayTreeMap.fromIterables([1, 2, 2], ["one", "two", "three"]);
+
Expect.isTrue(map is Map);
- Expect.isTrue(map is HashMap);
+ Expect.isTrue(map is SplayTreeMap);
+ Expect.isFalse(map is HashMap);
Expect.equals(2, map.length);
Expect.equals(2, map.keys.length);
@@ -61,13 +67,14 @@ void equalElementsTest() {
void genericTypeTest() {
- var map = new Map<int, String>.fromIterables(
+ var map = new SplayTreeMap<int, String>.fromIterables(
[1, 2, 3], ["one", "two", "three"]);
Expect.isTrue(map is Map<int, String>);
+ Expect.isTrue(map is SplayTreeMap<int, String>);
- // Make sure it is not just Map<dynamic, dynamic>.
- Expect.isFalse(map is Map<String, dynamic>);
- Expect.isFalse(map is Map<dynamic, int>);
+ // Make sure it is not just SplayTreeMap<dynamic, dynamic>.
+ Expect.isFalse(map is SplayTreeMap<String, dynamic>);
+ Expect.isFalse(map is SplayTreeMap<dynamic, int>);
Expect.equals(3, map.length);
Expect.equals(3, map.keys.length);
« no previous file with comments | « tests/corelib/splay_tree_from_iterable_test.dart ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698